import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_summary_model.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/ui/investment/investment_details.dart';
import 'package:flutter/material.dart';

class InvestmentCard extends StatelessWidget {
  final PortfolioSummaryData portfolioSummaryData;
  const InvestmentCard({Key? key, required this.portfolioSummaryData})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    num? indexPercentChange;
    if (portfolioSummaryData.investment?.stats?.indexValue != null &&
        portfolioSummaryData.investment?.stats?.lastCloseIndex != null) {
      final diff = portfolioSummaryData.investment!.stats!.lastCloseIndex! -
          portfolioSummaryData.investment!.stats!.indexValue!;
      indexPercentChange =
          (diff / portfolioSummaryData.investment!.stats!.indexValue!) * 100;
    }
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 5.0),
      child: InkWell(
        onTap: () {
          if (portfolioSummaryData.investment != null) {
            Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) => InvestmentDetails(
                        indexPercentChange: indexPercentChange,
                        investment: portfolioSummaryData.investment!)));
          }
        },
        child: Card(
          elevation: 0,
          shape: RoundedRectangleBorder(
              side: const BorderSide(color: Color(0xFFdde0e4), width: 1.0),
              borderRadius: BorderRadius.circular(10.0)),
          child: Padding(
            padding: const EdgeInsets.all(12.0),
            child: Column(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Row(
                      children: [
                        ErrorNetworkImageWidget(
                          src: portfolioSummaryData.investment?.imageUrl ?? "",
                          width: 30,
                          height: 30,
                        ),
                        const SizedBox(
                          width: 16.0,
                        ),
                        Text(
                          portfolioSummaryData.investment?.name ?? "--",
                          overflow: TextOverflow.ellipsis,
                          style: const TextStyle(
                              fontSize: 16.0, fontWeight: FontWeight.w600),
                        ),
                      ],
                    ),
                    const Align(
                      alignment: Alignment.centerRight,
                      child: Icon(
                        Icons.arrow_forward_ios_rounded,
                        size: 20,
                      ),
                    ),
                  ],
                ),
                const SizedBox(
                  height: 15,
                ),
                // const Divider(),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    ColumnCardInvestment(
                      title: Translations.of(context).indexVal,
                      //"Index Value",
                      subWidget: Row(
                        children: [
                          Text(
                            "${portfolioSummaryData.investment?.stats?.indexValue?.toStringAsFixed(2) ?? "--"}",
                            style: const TextStyle(
                                fontSize: 16.0, fontWeight: FontWeight.w500),
                          ),
                          if (indexPercentChange != null &&
                              indexPercentChange.isNegative)
                            const Icon(
                              Icons.arrow_drop_down,
                              size: 20,
                              color: Colors.red,
                            )
                          else
                            const Icon(
                              Icons.arrow_drop_up,
                              size: 20,
                              color: Colors.green,
                            ),
                          Text(
                            "${indexPercentChange?.toStringAsFixed(2)}",
                            style: TextStyle(
                                fontSize: 12.0,
                                fontWeight: FontWeight.w500,
                                color: indexPercentChange != null &&
                                        indexPercentChange.isNegative
                                    ? Colors.red
                                    : Colors.green),
                          ),
                        ],
                      ),
                    ),
                    ColumnCardInvestment(
                        title: Translations.of(context).currentVal,
                        subTitle:
                            "₹ ${portfolioSummaryData.investment?.returns?.insights?.currentValue != null ? indiaFormat.format(portfolioSummaryData.investment!.returns!.insights!.currentValue).replaceAll("INR", "") : "--"}"),
                    ColumnCardInvestment(
                      title: Translations.of(context).totalReturns,
                      subWidgetWithColor: Text(
                        "₹ ${portfolioSummaryData.investment?.returns?.insights?.totalReturns != null ? indiaFormat.format(portfolioSummaryData.investment!.returns!.insights!.totalReturns).replaceAll("INR", "") : "--"}",
                        style: TextStyle(
                            color: portfolioSummaryData.investment?.returns
                                            ?.insights?.totalReturns !=
                                        null &&
                                    portfolioSummaryData.investment!.returns!
                                        .insights!.totalReturns!.isNegative
                                ? Colors.red
                                : Colors.green,
                            fontSize: 16.0,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ],
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class ColumnCardInvestment extends StatelessWidget {
  final String title;
  final String? subTitle;
  final Widget? subWidget;
  final Widget? subWidgetWithColor;
  const ColumnCardInvestment(
      {Key? key,
      required this.title,
      this.subTitle,
      this.subWidget,
      this.subWidgetWithColor})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          title,
          overflow: TextOverflow.ellipsis,
          style: const TextStyle(
            fontSize: 11.0,
            fontWeight: FontWeight.w400,
            color: Colors.grey,
          ),
        ),
        const SizedBox(
          height: 5.0,
        ),
        if (subTitle != null)
          Text(
            subTitle!,
            overflow: TextOverflow.ellipsis,
            style: const TextStyle(fontSize: 16.0, fontWeight: FontWeight.w500),
          ),
        if (subWidgetWithColor != null) subWidgetWithColor!,
        if (subWidget != null) subWidget!,
        const SizedBox(
          height: 8.0,
        ),
      ],
    );
  }
}
